@@ -23,7 +23,7 @@ from __future__ import absolute_import
 
 from ._version import *       # noqa: F401
 from ._constants import *     # noqa: F401
-from ._exceptions import *    # noqa: F401
+from ._exceptions import *    # noqa: F401 pylint: disable=redefined-builtin
 from ._manager import *       # noqa: F401
 from ._resource import *      # noqa: F401
 from ._logging import *       # noqa: F401
@@ -56,3 +56,4 @@ from ._storage_volume import *         # noqa: F401
 from ._virtual_storage_resource import *        # noqa: F401
 from ._storage_group_template import *          # noqa: F401
 from ._storage_volume_template import *         # noqa: F401
+from ._capacity_group import *         # noqa: F401
