@@ -263,6 +263,8 @@ class Adapter(BaseResource):
         'osa': 'network-port-uris',
         'roce': 'network-port-uris',
         'hipersockets': 'network-port-uris',
+        'cna': 'network-port-uris',
+        'cloud-network': 'network-port-uris',  # for preliminary driver
     }
 
     # URI segment for port URIs, dependent on adapter family
@@ -271,6 +273,8 @@ class Adapter(BaseResource):
         'osa': 'network-ports',
         'roce': 'network-ports',
         'hipersockets': 'network-ports',
+        'cna': 'network-ports',
+        'cloud-network': 'network-ports',  # for preliminary driver
     }
 
     # Port type, dependent on adapter family
@@ -279,6 +283,8 @@ class Adapter(BaseResource):
         'osa': 'network',
         'roce': 'network',
         'hipersockets': 'network',
+        'cna': 'network',
+        'cloud-network': 'network',  # for preliminary driver
     }
 
     def __init__(self, manager, uri, name=None, properties=None):
@@ -419,9 +425,10 @@ class Adapter(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self.properties.get(self.manager._name_prop, None))
+            self._properties.get(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -448,12 +455,13 @@ class Adapter(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.post(self.uri, body=properties)
         is_rename = self.manager._name_prop in properties
         if is_rename:
             # Delete the old name from the cache
             self.manager._name_uri_cache.delete(self.name)
-        self.properties.update(copy.deepcopy(properties))
+        self._properties.update(copy.deepcopy(properties))
         if is_rename:
             # Add the new name to the cache
             self.manager._name_uri_cache.update(self.name, self.uri)
