@@ -25,9 +25,10 @@ import time
 
 from ._manager import BaseManager
 from ._resource import BaseResource
-from ._logging import get_logger, logged_api_call
+from ._logging import logged_api_call
 from ._utils import timestamp_from_datetime
 from ._storage_group import StorageGroupManager
+from ._storage_group_template import StorageGroupTemplateManager
 from ._user import UserManager
 from ._user_role import UserRoleManager
 from ._user_pattern import UserPatternManager
@@ -39,8 +40,6 @@ from ._unmanaged_cpc import UnmanagedCpcManager
 
 __all__ = ['ConsoleManager', 'Console']
 
-LOG = get_logger(__name__)
-
 
 class ConsoleManager(BaseManager):
     """
@@ -188,6 +187,7 @@ class Console(BaseResource):
 
         # The manager objects for child resources (with lazy initialization):
         self._storage_groups = None
+        self._storage_group_templates = None
         self._users = None
         self._user_roles = None
         self._user_patterns = None
@@ -207,6 +207,18 @@ class Console(BaseResource):
             self._storage_groups = StorageGroupManager(self)
         return self._storage_groups
 
+    @property
+    def storage_group_templates(self):
+        """
+        :class:`~zhmcclient.StorageGroupTemplateManager`:
+          Manager object for the Storage Group Templates in scope of this
+          Console.
+        """
+        # We do here some lazy loading.
+        if not self._storage_group_templates:
+            self._storage_group_templates = StorageGroupTemplateManager(self)
+        return self._storage_group_templates
+
     @property
     def users(self):
         """
@@ -467,7 +479,7 @@ class Console(BaseResource):
         """
         query_parms = self._time_query_parms(begin_time, end_time)
         uri = self.uri + '/operations/get-audit-log' + query_parms
-        result = self.manager.session.post(uri)
+        result = self.manager.session.get(uri)
         return result
 
     @logged_api_call
@@ -512,7 +524,7 @@ class Console(BaseResource):
         """
         query_parms = self._time_query_parms(begin_time, end_time)
         uri = self.uri + '/operations/get-security-log' + query_parms
-        result = self.manager.session.post(uri)
+        result = self.manager.session.get(uri)
         return result
 
     @logged_api_call
