@@ -227,9 +227,10 @@ class LdapServerDefinition(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self.properties.get(self.manager._name_prop, None))
+            self._properties.get(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -255,6 +256,7 @@ class LdapServerDefinition(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.post(self.uri, body=properties)
 
         # The name of LDAP Server Definitions cannot be updated. An attempt to
@@ -262,4 +264,4 @@ class LdapServerDefinition(BaseResource):
         # assert that here, because we omit the extra code for handling name
         # updates:
         assert self.manager._name_prop not in properties
-        self.properties.update(copy.deepcopy(properties))
+        self._properties.update(copy.deepcopy(properties))
