@@ -283,9 +283,10 @@ class Nic(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.delete(self._uri)
         self.manager._name_uri_cache.delete(
-            self.properties.get(self.manager._name_prop, None))
+            self._properties.get(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -313,12 +314,13 @@ class Nic(BaseResource):
           :exc:`~zhmcclient.AuthError`
           :exc:`~zhmcclient.ConnectionError`
         """
+        # pylint: disable=protected-access
         self.manager.session.post(self.uri, body=properties)
         is_rename = self.manager._name_prop in properties
         if is_rename:
             # Delete the old name from the cache
             self.manager._name_uri_cache.delete(self.name)
-        self.properties.update(copy.deepcopy(properties))
+        self._properties.update(copy.deepcopy(properties))
         if is_rename:
             # Add the new name to the cache
             self.manager._name_uri_cache.update(self.name, self.uri)
