@@ -274,7 +274,8 @@ class Session(object):
 
     def __init__(self, host, userid=None, password=None, session_id=None,
                  get_password=None, retry_timeout_config=None,
-                 port=DEFAULT_HMC_PORT):
+                 port=DEFAULT_HMC_PORT, verify_cert=True):
+        # pylint: disable=line-too-long
         """
         Creating a session object will not immediately cause a logon to be
         attempted; the logon is deferred until needed.
@@ -352,11 +353,41 @@ class Session(object):
             HMC TCP port. Defaults to
             :attr:`~zhmcclient._constants.DEFAULT_HMC_PORT`.
             For details, see the :attr:`~zhmcclient.Session.port` property.
-        """
+
+          verify_cert (bool or :term:`string`):
+            Controls whether and how the client verifies the server certificate
+            presented by the HMC during SSL/TLS handshake:
+
+            * `False`: Do not verify the HMC certificate. Not verifying the HMC
+              certificate means the zhmcclient will not detect hostname
+              mismatches, expired certificates, revoked certificates, or
+              otherwise invalid certificates. Since this mode makes the
+              connection vulnerable to man-in-the-middle attacks, it is insecure
+              and should not be used in production environments.
+
+            * `True`: Verify the HMC certificate using the CA certificates from
+              the first of these locations:
+
+              - The file or directory in the REQUESTS_CA_BUNDLE env.var, if set
+              - The file or directory in the CURL_CA_BUNDLE env.var, if set
+              - The Python 'certifi' package (which contains the
+                `Mozilla Included CA Certificate List <https://wiki.mozilla.org/CA/Included_Certificates>`_).
+
+            * :term:`string`: Path name of a certificate file or directory.
+              Verify the HMC certificate using the CA certificates in that file
+              or directory.
+
+            For details, see the :ref:`HMC certificate` section.
+
+            *Added in version 0.31*
+        """  # noqa: E501
+        # pylint: enable=line-too-long
+
         self._host = host
         self._port = port
         self._userid = userid
         self._password = password
+        self._verify_cert = verify_cert
         self._get_password = get_password
         self._retry_timeout_config = self.default_rt_config.override_with(
             retry_timeout_config)
@@ -386,6 +417,7 @@ class Session(object):
             "  _host={s._host!r},\n"
             "  _userid={s._userid!r},\n"
             "  _password='...',\n"
+            "  _verify_cert={s._verify_cert!r},\n"
             "  _get_password={s._get_password!r},\n"
             "  _retry_timeout_config={s._retry_timeout_config!r},\n"
             "  _base_url={s._base_url!r},\n"
@@ -428,6 +460,16 @@ class Session(object):
         """
         return self._userid
 
+    @property
+    def verify_cert(self):
+        """
+        bool or :term:`string`: Controls whether and how the client verifies
+        server certificate presented by the HMC during SSL/TLS handshake.
+
+        For details, see the same-named init parameter.
+        """
+        return self._verify_cert
+
     @property
     def get_password(self):
         """
@@ -620,7 +662,7 @@ class Session(object):
         Return a new `requests.Session` object.
         """
         retry = urllib3.Retry(
-            total=None,
+            total=retry_timeout_config.connect_retries,
             connect=retry_timeout_config.connect_retries,
             read=retry_timeout_config.read_retries,
             method_whitelist=retry_timeout_config.method_whitelist,
@@ -663,11 +705,13 @@ class Session(object):
           headers (iterable): HTTP headers used for the request
 
           content (:term:`string`): HTTP body (aka content) used for the
-            request
+            request (byte string or unicode string)
         """
 
         content_msg = None
         if content is not None:
+            if isinstance(content, six.binary_type):
+                content = content.decode('utf-8')
             content_len = len(content)  # may change after JSON conversion
             try:
                 content_dict = json2dict(content)
@@ -711,10 +755,12 @@ class Session(object):
           headers (iterable): HTTP headers returned in the response
 
           content (:term:`string`): HTTP body (aka content) returned in the
-            response
+            response (byte string or unicode string)
         """
 
         if content is not None:
+            if isinstance(content, six.binary_type):
+                content = content.decode('utf-8')
             content_len = len(content)  # may change after JSON conversion
             try:
                 content_dict = json2dict(content)
@@ -798,9 +844,11 @@ class Session(object):
         req_timeout = (self.retry_timeout_config.connect_timeout,
                        self.retry_timeout_config.read_timeout)
         try:
-            result = req.get(url, headers=self.headers, verify=False,
+            result = req.get(url, headers=self.headers, verify=self.verify_cert,
                              timeout=req_timeout)
-        except requests.exceptions.RequestException as exc:
+        # Note: The requests method may raise OSError/IOError in case of
+        # HMC certificate validation issues (e.g. incorrect cert path)
+        except (requests.exceptions.RequestException, IOError, OSError) as exc:
             _handle_request_exc(exc, self.retry_timeout_config)
         finally:
             stats.end()
@@ -979,11 +1027,16 @@ class Session(object):
             try:
                 if data is None:
                     result = req.post(url, headers=headers,
-                                      verify=False, timeout=req_timeout)
+                                      verify=self.verify_cert,
+                                      timeout=req_timeout)
                 else:
                     result = req.post(url, data=data, headers=headers,
-                                      verify=False, timeout=req_timeout)
-            except requests.exceptions.RequestException as exc:
+                                      verify=self.verify_cert,
+                                      timeout=req_timeout)
+            # Note: The requests method may raise OSError/IOError in case of
+            # HMC certificate validation issues (e.g. incorrect cert path)
+            except (requests.exceptions.RequestException, IOError, OSError) \
+                    as exc:
                 _handle_request_exc(exc, self.retry_timeout_config)
             finally:
                 stats.end()
@@ -1083,9 +1136,11 @@ class Session(object):
         req_timeout = (self.retry_timeout_config.connect_timeout,
                        self.retry_timeout_config.read_timeout)
         try:
-            result = req.delete(url, headers=self.headers, verify=False,
-                                timeout=req_timeout)
-        except requests.exceptions.RequestException as exc:
+            result = req.delete(url, headers=self.headers,
+                                verify=self.verify_cert, timeout=req_timeout)
+        # Note: The requests method may raise OSError/IOError in case of
+        # HMC certificate validation issues (e.g. incorrect cert path)
+        except (requests.exceptions.RequestException, IOError, OSError) as exc:
             _handle_request_exc(exc, self.retry_timeout_config)
         finally:
             stats.end()
@@ -1481,7 +1536,7 @@ def json2dict(json_str):
     Convert a JSON string into a dict.
 
     Parameters:
-      json_str(string): Unicode or binary string in JSON format.
+      json_str (string): Unicode or binary string in JSON format.
 
     Returns:
       dict: JSON string converted to a dict.
@@ -1502,10 +1557,11 @@ def dict2json(json_dict):
     Convert a dict into a JSON string.
 
     Parameters:
-      json_dict(dict): The dict.
+      json_dict (dict): The dict.
 
     Returns:
-      dict: The dict converted to a Unicode JSON string.
+      unicode string (py3) or byte string (py2): Dict converted to a JSON
+      string.
     """
     json_str = json.dumps(json_dict)
     return json_str
