@@ -236,7 +236,7 @@ class UserRole(BaseResource):
         # pylint: disable=protected-access
         self.manager.session.delete(self.uri)
         self.manager._name_uri_cache.delete(
-            self.properties.get(self.manager._name_prop, None))
+            self._properties.get(self.manager._name_prop, None))
 
     @logged_api_call
     def update_properties(self, properties):
@@ -272,7 +272,7 @@ class UserRole(BaseResource):
         # cause HTTPError to be raised in the POST above, so we assert that
         # here, because we omit the extra code for handling name updates:
         assert self.manager._name_prop not in properties
-        self.properties.update(copy.deepcopy(properties))
+        self._properties.update(copy.deepcopy(properties))
 
     @logged_api_call
     def add_permission(self, permitted_object, include_members=False,
