@@ -18,7 +18,7 @@ zhmcclient_mock - Unit test support for users of the zhmcclient package.
 
 from __future__ import absolute_import
 
-from ._session import *       # noqa: F401
+from ._session import *       # noqa: F401 pylint: disable=redefined-builtin
 from ._urihandler import *    # noqa: F401
 from ._hmc import *           # noqa: F401
 from ._idpool import *        # noqa: F401
